package simulation;

import java.util.PriorityQueue;

// Wrapper class for a priority queue of events
// Changed from a linked list to a priority queue better suited for this type of application
public class EventList {

	// A heap backed, event containing priority queue.
	private PriorityQueue<Event> pq = new PriorityQueue<>();
	// This one contains events that are prioritized over the normal events
	private PriorityQueue<Event> high_pq = new PriorityQueue<>();

	// This is a helper function to get the correct queue
	private PriorityQueue<Event> getQueue() {
		return switch (high_pq.size()) {
			case 0 -> pq; // If no priority events, return normal queue
			default -> high_pq; // If priority events, return priority queue
		};
	}

	public Event getHead() {
		return getQueue().peek();
	}

	public Integer length() {
		return getQueue().size();
	}

	public void insertEvent(Event newEvent) {
		pq.add(newEvent);
	}

	public void insertPriorityEvent(Event newEvent) {
		high_pq.add(newEvent);
	}

	public Event popEvent() {
		return getQueue().poll();
	}
}
